@@ -68,11 +68,11 @@ class Runtime:
         :param min_required_version: Minimal version of Ansible required. If
                                      not found, a :class:`RuntimeError`
                                      exception is raised.
-        :param: require_module: If set, instantiation will fail if Ansible
-                                Python module is missing or is not matching
-                                the same version as the Ansible command line.
-                                That is useful for consumers that expect to
-                                also perform Python imports from Ansible.
+        :param require_module: If set, instantiation will fail if Ansible
+                               Python module is missing or is not matching
+                               the same version as the Ansible command line.
+                               That is useful for consumers that expect to
+                               also perform Python imports from Ansible.
         :param max_retries: Number of times it should retry network operations.
                             Default is 0, no retries.
         :param environ: Environment dictionary to use, if undefined
@@ -123,6 +123,25 @@ class Runtime:
                 "indicates a broken execution environment."
             )
 
+        # For ansible 2.15+ we need to initialize the plugin loader
+        # https://github.com/ansible/ansible-lint/issues/2945
+        if self.version >= Version("2.15.0.dev0"):
+            # pylint: disable=import-outside-toplevel
+            from ansible.plugins.loader import init_plugin_loader
+
+            init_plugin_loader([])
+        else:
+            # noinspection PyProtectedMember
+            from ansible.utils.collection_loader._collection_finder import (  # pylint: disable=import-outside-toplevel
+                _AnsibleCollectionFinder,
+            )
+
+            # noinspection PyProtectedMember
+            # pylint: disable=protected-access
+            _AnsibleCollectionFinder(
+                paths=[os.path.dirname(os.environ.get(ansible_collections_path(), "."))]
+            )._install()  # pylint: disable=protected-access
+
     def clean(self) -> None:
         """Remove content of cache_dir."""
         if self.cache_dir:
@@ -158,6 +177,7 @@ class Runtime:
             )
             if result.returncode == 0:
                 break
+            _logger.debug("Environment: %s", env or self.environ)
             _logger.warning(
                 "Retrying execution failure %s of: %s",
                 result.returncode,
@@ -211,12 +231,9 @@ class Runtime:
             "ansible-galaxy",
             "collection",
             "install",
-            "-v",
+            "-vvv",  # this is needed to make ansible display important info in case of failures
         ]
-
-        # ansible-galaxy before 2.11 fails to upgrade collection unless --force
-        # is present, newer versions do not need it
-        if force or self.version_in_range(upper="2.11"):
+        if force:
             cmd.append("--force")
 
         # As ansible-galaxy install is not able to automatically determine
@@ -230,7 +247,7 @@ class Runtime:
             cmd.extend(["-p", str(destination)])
         cmd.append(f"{collection}")
 
-        _logger.info("Running %s", " ".join(cmd))
+        _logger.info("Running from %s : %s", os.getcwd(), " ".join(cmd))
         run = self.exec(
             cmd,
             retry=True,
@@ -269,8 +286,15 @@ class Runtime:
                     force=True,
                 )
 
-    def install_requirements(self, requirement: str, retry: bool = False) -> None:
-        """Install dependencies from a requirements.yml."""
+    def install_requirements(
+        self, requirement: str, retry: bool = False, offline: bool = False
+    ) -> None:
+        """Install dependencies from a requirements.yml.
+
+        :param requirement: path to requirements.yml file
+        :param retry: retry network operations on failures
+        :param offline: bypass installation, may fail if requirements are not met.
+        """
         if not os.path.exists(requirement):
             return
         reqs_yaml = yaml_from_file(requirement)
@@ -290,11 +314,17 @@ class Runtime:
             if self.cache_dir:
                 cmd.extend(["--roles-path", f"{self.cache_dir}/roles"])
 
-            _logger.info("Running %s", " ".join(cmd))
-            run = self.exec(cmd, retry=retry)
-            if run.returncode != 0:
-                _logger.error(run.stdout)
-                raise AnsibleCommandError(run)
+            if offline:
+                _logger.warning(
+                    "Skipped installing old role dependencies due to running in offline mode."
+                )
+            else:
+                _logger.info("Running %s", " ".join(cmd))
+
+                result = self.exec(cmd, retry=retry)
+                if result.returncode != 0:
+                    _logger.error(result.stdout)
+                    raise AnsibleCommandError(result)
 
         # Run galaxy collection install works on v2 requirements.yml
         if "collections" in reqs_yaml:
@@ -303,17 +333,22 @@ class Runtime:
                 "ansible-galaxy",
                 "collection",
                 "install",
-                "-vr",
-                f"{requirement}",
+                "-v",
             ]
-            if self.cache_dir:
-                cmd.extend(["-p", f"{self.cache_dir}/collections"])
-
-            _logger.info("Running %s", " ".join(cmd))
-            run = self.exec(cmd, retry=retry)
-            if run.returncode != 0:
-                _logger.error(run.stdout)
-                raise AnsibleCommandError(run)
+            if offline:
+                _logger.warning(
+                    "Skipped installing collection dependencies due to running in offline mode."
+                )
+            else:
+                cmd.extend(["-r", requirement])
+                if self.cache_dir:
+                    cmd.extend(["-p", f"{self.cache_dir}/collections"])
+                _logger.info("Running %s", " ".join(cmd))
+                result = self.exec(cmd, retry=retry)
+                if result.returncode != 0:
+                    _logger.error(result.stdout)
+                    _logger.error(result.stderr)
+                    raise AnsibleCommandError(result)
 
     def prepare_environment(  # noqa: C901
         self,
@@ -327,17 +362,16 @@ class Runtime:
         if required_collections is None:
             required_collections = {}
 
-        if not offline:
-            # first one is standard for collection layout repos and the last two
-            # are part of Tower specification
-            # https://docs.ansible.com/ansible-tower/latest/html/userguide/projects.html#ansible-galaxy-support
-            # https://docs.ansible.com/ansible-tower/latest/html/userguide/projects.html#collections-support
-            for req_file in [
-                "requirements.yml",
-                "roles/requirements.yml",
-                "collections/requirements.yml",
-            ]:
-                self.install_requirements(req_file, retry=retry)
+        # first one is standard for collection layout repos and the last two
+        # are part of Tower specification
+        # https://docs.ansible.com/ansible-tower/latest/html/userguide/projects.html#ansible-galaxy-support
+        # https://docs.ansible.com/ansible-tower/latest/html/userguide/projects.html#collections-support
+        for req_file in [
+            "requirements.yml",
+            "roles/requirements.yml",
+            "collections/requirements.yml",
+        ]:
+            self.install_requirements(req_file, retry=retry, offline=offline)
 
         destination = f"{self.cache_dir}/collections" if self.cache_dir else None
         for name, min_version in required_collections.items():
